@@ -7,7 +7,7 @@ from .classes.fluent_assert import verify
 from .classes.soft_assert import SoftAssert
 from .classes.listeners.file_logger import DefaultFileListener
 
-__all__ = ['start', 'common_parameters', 'SoftAssert', 'Spy', 'Double', 'DefaultFileListener', 'DATA_FILE',
+__all__ = ['start', 'common_parameters', 'SoftAssert', 'Spy', 'Double', 'DefaultFileListener', 'DATA_FILE', 'CONTAINER',
            'equals', 'is_none', 'not_none', 'waiting_exception', 'test_fail', 'test_brake', 'no_exception_expected',
            'contains', 'verify', 'not_contains', 'not_equals', 'is_false', 'is_true', 'mock_builtins', 'mock',
            'is_zero', 'is_positive', 'is_negative',
