@@ -60,6 +60,8 @@ def start(verbose: int = 0, listener: Listener = None, groups: List[str] = None,
         threads = 1
     if dry_run:
         _dry_run(test_suite)
+    # Check if all used provider names are found
+    _check_data_providers(test_suite)
     _run(test_suite, threads)
 
 
@@ -84,14 +86,13 @@ def _dry_run(test_suite):
 def _run(test_suite: TestSuite, threads: int = 1):
     # Create a pool of threads to run tests, by default 1 thread execution
     pool = ThreadPoolExecutor(max_workers=threads)
+    test_suite.start_suite()
     _listener.on_suite_starts(test_suite)
     try:
         # If the fixture before the test suite has fallen, then will not run the tests (fixture after the test suite
         # will be executed with the appropriate flag)
         if not _run_before_suite(test_suite):
             return
-        # Check if all used provider names are found
-        _check_data_providers(test_suite)
         for group in test_suite.groups.values():
             # If there are no tests in the group, then skip it
             if not group.tests:
@@ -100,6 +101,7 @@ def _run(test_suite: TestSuite, threads: int = 1):
         pool.shutdown(wait=True)
         _run_after(test_suite)
     finally:
+        test_suite.stop_suite()
         _listener.on_suite_ends(test_suite)
 
 
@@ -112,6 +114,11 @@ def _run_group_before_and_after_at_separate_thread(group: TestGroup):
 
 
 def _run_before_suite(test_suite: TestSuite) -> bool:
+    """
+    Run fixtures before whole suite.
+    :param test_suite: TestSuite
+    :return: True if fixture is not fail, False otherwise
+    """
     _run_before(test_suite)
     if test_suite.is_before_failed:
         _listener.on_before_suite_failed(test_suite)
@@ -122,17 +129,28 @@ def _run_before_suite(test_suite: TestSuite) -> bool:
 
 
 def _run_before_group(group: TestGroup) -> bool:
+    """
+    Runs before group fixtures
+    :param group: TestGroup
+    :return: True if fixtures not failed, False otherwise
+    """
     _run_before(group)
     if group.is_before_failed:
         for test in group.tests:
-            _listener.on_ignored(group, test, 'before module/group')
+            test.stop(TestIgnoredException('Before module/group failed!'))
+            _listener.on_ignored(test, 'before module/group')
         if group.always_run_after:
             _run_after(group)
         return False
     return True
 
 
-def _run_test_with_provider(test, group):
+def _run_test_with_provider(test):
+    """
+    Run test which has provider
+    :param test: Test
+    :return: None
+    """
     generator = _provider_next(test.provider)
     try:
         is_any_value_provides = False
@@ -140,45 +158,53 @@ def _run_test_with_provider(test, group):
             is_any_value_provides = True
             clone = test.clone()
             clone.argument = param
-            is_one_of_before_test_failed = _run_test_with_before_and_after(clone, group, False)
+            is_one_of_before_test_failed = _run_test_with_before_and_after(clone, False)
             if is_one_of_before_test_failed:
                 print(f'Because of "before_test" all tests for {test} with data provider '
                       f'"{test.provider}" was IGNORED!')
                 break
         # If no values at provider - ignore test
         if not is_any_value_provides:
-            _listener.on_ignored_with_provider(test, group)
+            test.stop(TestIgnoredException(f'No values at provider {test.provider}'))
+            _listener.on_ignored_with_provider(test)
     except TypeError as e:
         if 'is not iterable' not in e.args[0]:
             print(e)
             raise
         else:
-            _listener.on_ignored_with_provider(test, group)
+            test.stop(TestIgnoredException(f'Error with provider {test.provider}'))
+            _listener.on_ignored_with_provider(test)
 
 
 def _run_all_tests_in_group(group: TestGroup):
+    """
+    Run all test of the group, after sorting them by priority
+    :param group: TestGroup
+    :return: None
+    """
     is_one_of_before_test_failed = False
     group.sort_test_by_priority()
     for test in group.tests:
         if test.provider:
-            _run_test_with_provider(test, group)
+            _run_test_with_provider(test)
         else:
-            is_one_of_before_test_failed = _run_test_with_before_and_after(test, group, is_one_of_before_test_failed)
+            is_one_of_before_test_failed = _run_test_with_before_and_after(test, is_one_of_before_test_failed)
 
 
-def _run_test_with_before_and_after(test: Test, group: TestGroup, is_before_failed: bool) -> bool:
+def _run_test_with_before_and_after(test: Test, is_before_failed: bool) -> bool:
     if not is_before_failed:
         _run_before(test)
     else:
         test.is_before_failed = True
     if test.is_before_failed:
-        _listener.on_ignored(group, test, 'before test')
+        test.stop(TestIgnoredException('Before test failed!'))
+        _listener.on_ignored(test, 'before test')
         return True
     for retry in range(test.retries):
         clone = test.clone()
         if retry > 0:
             clone.name = clone.name + f' ({retry})'
-        result = _run_test(clone, group)
+        result = _run_test(clone)
         if result:
             break
     _run_after(test)
@@ -186,6 +212,12 @@ def _run_test_with_before_and_after(test: Test, group: TestGroup, is_before_fail
 
 
 def _provider_next(provider_name: str) -> Any:
+    """
+    Gets provider functions return or yield(generator) and iterate it. If a close attribute exists (for files) try to
+    close recourse after getting all elements.
+    :param provider_name: name of the provider
+    :return: generator
+    """
     iter_ = TestSuite.get_instance().providers[provider_name]()
     for param in iter_:
         yield param
@@ -199,25 +231,40 @@ def _provider_next(provider_name: str) -> Any:
             # explicitly ignore
 
 
-def _run_test(test: Test, group: TestGroup) -> bool:
-    _listener.on_test_starts(test, group)
+def _run_test(test: Test) -> bool:
+    """
+    Run actual test
+    :param test: Test (function to run)
+    :return: True if test succeed, False otherwise
+    """
+    _listener.on_test_starts(test)
     try:
         if test.timeout:
             run_with_timeout(test)
         else:
             test.run()
-        _listener.on_success(group, test)
+        test.stop()
+        _listener.on_success(test)
         return True
     except AssertionError as e:
-        _listener.on_failed(group, test, e)
+        test.stop(e)
+        _listener.on_failed(test, e)
     except (TestIgnoredException, SystemExit) as e:
-        _listener.on_ignored_by_condition(group, test, e)
+        test.stop(e)
+        _listener.on_ignored_by_condition(test, e)
     except Exception as e:
-        _listener.on_broken(group, test, e)
+        test.stop(e)
+        _listener.on_broken(test, e)
     return False
 
 
 def _check_data_providers(suite: TestSuite):
+    """
+    Checks if any test use data-provider, this provider is in collected list
+    :param suite: TestSuite
+    :return: None
+    :raises UnknownProviderName if test uses name what is not in providers list
+    """
     all_data_providers = [test.provider for group in suite.groups.values() for test in group.tests if test.provider]
     if not all_data_providers:
         return
@@ -229,6 +276,11 @@ def _check_data_providers(suite: TestSuite):
 
 
 def _run_before(test_case: TestCase):
+    """
+    Runs all fixtures before test case. If failed - set flaf is_before_failed to True
+    :param test_case: Test or TestGroup
+    :return: None
+    """
     for before in test_case.before:
         result = _run_fixture(before, 'before', test_case.name)
         if result:
@@ -236,6 +288,11 @@ def _run_before(test_case: TestCase):
 
 
 def _run_after(test_case: TestCase):
+    """
+    Runs all fixtures after test or group
+    :param test_case: Test or TestGroup
+    :return: None
+    """
     if not test_case.always_run_after and test_case.is_before_failed:
         return
     for after in test_case.after:
@@ -243,6 +300,13 @@ def _run_after(test_case: TestCase):
 
 
 def _run_fixture(func: Callable, fixture_type: str, group_name: str) -> bool:
+    """
+    Runs fixture and returns result of the run
+    :param func: fixture-function (marked @before etc.)
+    :param fixture_type: type of the fixture to use in listener (before, after ...)
+    :param group_name: name of the group
+    :return: False if fixture not failed, True otherwise
+    """
     is_failed: bool = False
     try:
         func()
